"""
    schema: Survey Message that is decoded sent by platforms
    to track progress
"""

survey_schema = {
    "type": "object",
    "properties": {
        "timestamp": {
            "type": "string",
            "format": "date-time",
            "description": "Timestamp for onboard message",
            "example": "2022-12-21T00:00:00Z",
        },
        "latitude_A": {
            "type": "number",
            "format": "float",
            "description": (
                "Latitude of point A(intersection of normal)"
                + "from waypoint A to survey line"
            ),
            "example": 178.2,
        },
        "longitude_A": {
            "type": "number",
            "format": "float",
            "description": (
                "Longitude of point A(intersection of normal)"
                + "from waypoint A to survey line"
            ),
            "example": -10.122,
        },
        "latitude_B": {
            "type": "number",
            "format": "float",
            "description": (
                "Latitude of point B(intersection of normal)"
                + "from waypoint B to survey line"
            ),
            "example": 178.2,
        },
        "longitude_B": {
            "type": "number",
            "format": "float",
            "description": (
                "Longitude of point B(intersection of normal)"
                + "from waypoint B to survey line"
            ),
            "example": -10.122,
        },
        "latitude_C": {
            "type": "number",
            "format": "float",
            "description": (
                "Latitude of point C(intersection of normal)"
                + "from waypoint C to survey line"
            ),
            "example": 178.2,
        },
        "longitude_C": {
            "type": "number",
            "format": "float",
            "description": (
                "Longitude of point C(intersection of normal)"
                + "from waypoint C to survey line"
            ),
            "example": -10.122,
        },
        "latitude_D": {
            "type": "number",
            "format": "float",
            "description": (
                "Latitude of point D(intersection of normal)"
                + "from waypoint D to survey line"
            ),
            "example": 178.2,
        },
        "longitude_D": {
            "type": "number",
            "format": "float",
            "description": (
                "Longitude of point D(intersection of normal)"
                + "from waypoint D to survey line"
            ),
            "example": -10.122,
        },
        "latitude_E": {
            "type": "number",
            "format": "float",
            "description": (
                "Latitude of point E(intersection of normal)"
                + "from waypoint E to survey line"
            ),
            "example": 178.2,
        },
        "longitude_E": {
            "type": "number",
            "format": "float",
            "description": (
                "Longitude of point E(intersection of normal)"
                + "from waypoint E to survey line"
            ),
            "example": -10.122,
        },
        "platform_ID": {
            "type": "string",
            "description": "Unique identifier for this platform",
            "example": "ecosub-2",
        },
        "track_ID": {
            "type": "integer",
            "description": "Track number of action(s) currently executed by platform",
            "example": 1,
        },
    },
    "required": [
        "latitude_A",
        "longitude_A",
        "latitude_B",
        "longitude_B",
        "platform_ID",
    ],
}
